@@ -1,6 +1,6 @@
 package PMLTQ::Commands;
 our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Commands::VERSION = '1.0.1';
+$PMLTQ::Commands::VERSION = '1.1.0';
 # ABSTRACT: PMLTQ command line interface
 
 use PMLTQ::Base -strict;
@@ -136,14 +136,15 @@ sub _load_config {
   $config->{db}->{name} = $config->{treebank_id} if ( $config->{treebank_id} && !$config->{db}->{name} );
 
   for ( grep { $config->{$_} } qw/data_dir resources output_dir/ ) {
-    $config->{$_} = File::Spec->rel2abs( $config->{$_}, $base_dir );
+    $config->{$_} = abs_path( File::Spec->rel2abs( $config->{$_}, $base_dir ) );
   }
 
   if ( $config->{layers} ) {
     for my $lr ( @{ $config->{layers} } ) {
-      $lr->{'related-schema'} = [ map { File::Spec->rel2abs( $_, $config->{resources} ) } @{ $lr->{'related-schema'} } ]
+      $lr->{'related-schema'} =
+        [ map { abs_path( File::Spec->rel2abs( $_, $config->{resources} ) ) } @{ $lr->{'related-schema'} } ]
         if $lr->{'related-schema'};
-      $lr->{filelist} = File::Spec->rel2abs( $lr->{filelist}, $base_dir )
+      $lr->{filelist} = abs_path( File::Spec->rel2abs( $lr->{filelist}, $base_dir ) )
         if $lr->{filelist} && !File::Spec->file_name_is_absolute( $lr->{filelist} );
     }
   }
@@ -165,7 +166,7 @@ PMLTQ::Commands - PMLTQ command line interface
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 SYNOPSIS
 
