@@ -1,6 +1,6 @@
 package PMLTQ::PML2BASE;
 our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::PML2BASE::VERSION = '1.0.1';
+$PMLTQ::PML2BASE::VERSION = '1.1.0';
 # ABSTRACT: Convert from PML to SQL
 
 
@@ -412,7 +412,7 @@ sub _abs2rel {
 sub abs2rel {
   my ($file)=@_;
   my $ret = _abs2rel($file);
-  croak "Incorrect --data-dir value '$opts{'data-dir'}' (resolved to '$ret') or invalid filename '$file'\n"
+  croak "Incorrect --data_dir value '$opts{'data-dir'}' (resolved to '$ret') or invalid filename '$file'\n"
     ."Explanation: Paths stored in the database should not start with ../ since this breaks URLs"
       if $ret=~m{^\.\.};
   return $ret;
@@ -891,6 +891,11 @@ sub traverse_data {
         my $mdump = traverse_data($d,$v);
         $desc->{$n} = data_index($mdump);
       } else {
+        # HACK for Interset structure
+        if (ref $v && UNIVERSAL::DOES::does($value, 'Lingua::Interset::FeatureStructure')) {
+          $v = [ map { $_ . '=' . $v->{$_} } keys %$v ] if ref $v eq 'HASH';
+          $v = join ('|', @$v) if ref $v eq 'ARRAY';
+        }
         my ($key,$value) = col_val($d,$table,$n,$v);
         $desc->{$key} = $value;
       }
@@ -1345,7 +1350,7 @@ PMLTQ::PML2BASE - Convert from PML to SQL
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 DESCRIPTION
 
